#    Copyright 2023 Stanford University Convex Optimization Group
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
"""DataAPI for {{ strategy }}"""
# This class has been generated by cvxbson
from dataclasses import dataclass, field
from typing import Dict

import polars as pl

from cvx.bson.dataclass import Data

@dataclass(frozen=True)
class DataAPI(Data):
    # List of tables
    {% for name in names.keys() %}
    {{ name }}: pl.DataFrame
    {% endfor %}

    # Mapping from short name to full name
    tables: Dict[str, str] = field(default_factory=lambda: {{ names }})
